format

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 25, 2024 License: AGPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Format

func Format(syntaFile synta.Synta) (code string)

Format formats a synta structure into a string which represnts the contents of the associated synta file. The definitions are sorted by name. and blank lines are let as per internal convention.

Types

This section is empty.

Jump to